@@ -32,7 +32,7 @@ class TQPopupMenu;
 
 class KRomajiEdit : public KLineEdit
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
