@@ -807,7 +807,7 @@ TDEInstance* KmPlotPartFactory::instance()
 
 extern "C"
 {
-	KDE_EXPORT void* init_libkmplotpart()
+	TDE_EXPORT void* init_libkmplotpart()
 	{
 		return new KmPlotPartFactory;
 	}
