@@ -38,7 +38,7 @@ class SettingsPageCoords;
 /// 
 class CoordsConfigDialog : public TDEConfigDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		CoordsConfigDialog(XParser *p, TQWidget *parent = 0);
