@@ -287,10 +287,10 @@ void INDI_E::setupElementScale(int length)
 
 int steps = (int) ((max - min) / step);
 spin_w    = new KDoubleSpinBox(min, max, step, value, 2, pp->pg->propertyContainer );
-slider_w  = new TQSlider(0, steps, 1, (int) ((value - min) / step),  Qt::Horizontal, pp->pg->propertyContainer );
+slider_w  = new TQSlider(0, steps, 1, (int) ((value - min) / step),  TQt::Horizontal, pp->pg->propertyContainer );
 
-connect(spin_w, TQT_SIGNAL(valueChanged(double)), this, TQT_SLOT(spinChanged(double )));
-connect(slider_w, TQT_SIGNAL(sliderMoved(int)), this, TQT_SLOT(sliderChanged(int )));
+connect(spin_w, TQ_SIGNAL(valueChanged(double)), this, TQ_SLOT(spinChanged(double )));
+connect(slider_w, TQ_SIGNAL(sliderMoved(int)), this, TQ_SLOT(sliderChanged(int )));
 
 //kdDebug() << "For element " << label << " we have step of " << step << endl;
 
@@ -363,7 +363,7 @@ void INDI_E::setupElementWrite(int length)
     write_w->setMinimumWidth( length );
     write_w->setMaximumWidth( length);
     
-    TQObject::connect(write_w, TQT_SIGNAL(returnPressed()), pp, TQT_SLOT(newText()));
+    TQObject::connect(write_w, TQ_SIGNAL(returnPressed()), pp, TQ_SLOT(newText()));
     EHBox->addWidget(write_w);
 }
 
@@ -378,7 +378,7 @@ void INDI_E::setupElementRead(int length)
   read_w->setFrameShadow( KLineEdit::Plain );
   read_w->setCursorPosition( 0 );
   read_w->setAlignment( int( KLineEdit::AlignHCenter ) );
-  read_w->setReadOnly( TRUE );
+  read_w->setReadOnly( true );
   read_w->setText(text);
   
   EHBox->addWidget(read_w);
@@ -393,7 +393,7 @@ void INDI_E::setupBrowseButton()
    browse_w->setMaximumWidth( MAX_SET_WIDTH );
 
    EHBox->addWidget(browse_w);
-   TQObject::connect(browse_w, TQT_SIGNAL(clicked()), this, TQT_SLOT(browseBlob()));
+   TQObject::connect(browse_w, TQ_SIGNAL(clicked()), this, TQ_SLOT(browseBlob()));
 }
 
 
