@@ -37,7 +37,7 @@ class StarDataSink : public TQObject, public TQDataSink {
 /**
 	*class needs signals
 	*/
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
