@@ -65,7 +65,7 @@ void kvoctrainApp::slotTimeOutBackup()
     slotFileSave();
   }
   if (Prefs::backupTime() > 0)
-    btimer->start(Prefs::backupTime() * 60 * 1000, TRUE);
+    btimer->start(Prefs::backupTime() * 60 * 1000, true);
   slotStatusMsg(IDS_DEFAULT);
 }
 
