@@ -144,7 +144,7 @@ void AdjQueryDlg::setQuery(TQString,
        timercount = mqtime;
        mw->timebar->setTotalSteps(timercount);
        mw->timebar->setProgress(timercount);
-       qtimer->start(1000, TRUE);
+       qtimer->start(1000, true);
      }
      else
        mw->timebar->setEnabled(false);
@@ -216,7 +216,7 @@ void AdjQueryDlg::timeoutReached()
    if (timercount > 0) {
      timercount--;
      mw->timebar->setProgress(timercount);
-     qtimer->start(1000, TRUE);
+     qtimer->start(1000, true);
    }
 
    if (timercount <= 0) {
