@@ -26,7 +26,7 @@
 */
 class DlgRC : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
   DlgRC(TQWidget *parent = 0, const char *name = 0, bool modal=true);
